@@ -1,10 +1,12 @@
 import asyncio
+import signal
 import sys
+from functools import partial
 from pathlib import Path
 
 import click
 import pkg_resources
-from PySide2.QtWidgets import QApplication
+from PyQt5.QtWidgets import QApplication
 from qasync import QEventLoop
 
 from fastocr import __appname__
@@ -35,10 +37,18 @@ def run():
     if sys.platform not in ['win32', 'darwin', 'cygwin'] and instance_already_running():
         print('Only one instance allowed')
         sys.exit(1)
+
+    def quit_application(code):
+        QApplication.quit()
+        sys.exit(code)
+
     app = QApplication(sys.argv)
     Translation().load().install(app)
     loop = QEventLoop(app)
     asyncio.set_event_loop(loop)
+    loop = asyncio.get_event_loop()
+    for s in [signal.SIGINT, signal.SIGTERM]:
+        loop.add_signal_handler(s, partial(quit_application, s))
     if DesktopInfo.dbus_supported():
         from fastocr.bus import app_dbus
         app_dbus.tray = AppTray(bus=app_dbus)
@@ -69,19 +79,20 @@ def diagnose():
     print('== Application ==')
     print(f'Version: {__version__}')
     print(f'File: {__file__}')
-    print(f'Running: {instance_already_running()}')
+    if sys.platform not in ['win32', 'darwin', 'cgywin']:
+        print(f'Running: {instance_already_running()}')
     print()
     # Environment
     print('== Environment ==')
-    import platform, PySide2.QtCore
+    import platform, PyQt5.QtCore
     _version = sys.version.replace('\n', ' ')
     print(f'System: {platform.system()} {platform.version()}')
     print(f'Info: {" ".join(platform.uname())}')
     print(f'Python: {_version}')
     print(f'Platform: {sys.platform}')
     # noinspection PyUnresolvedReferences
-    print(f'PySide2 Qt: {PySide2.QtCore.__version__}')
-    print(f'Running Qt: {PySide2.QtCore.qVersion()}')
+    print(f'PySide2 Qt: {PyQt5.QtCore.__version__}')
+    print(f'Running Qt: {PyQt5.QtCore.qVersion()}')
     print(f'DBus: {DesktopInfo.dbus_supported()}')
     if sys.platform not in ['win32', 'darwin', 'cygwin']:
         print(f'Desktop: {DesktopInfo.desktop_environment()}')
@@ -89,7 +100,7 @@ def diagnose():
     print()
 
     # Dependency
-    packages = ['PySide2', 'shiboken2', 'aiohttp']
+    packages = ['PyQt5', 'aiohttp']
     if sys.platform not in ['win32', 'darwin', 'cygwin']:
         packages.append('dbus')
     for p in packages:
