@@ -5,15 +5,19 @@ from pathlib import Path
 from typing import Optional, List
 
 import qasync
-from PySide2.QtCore import QByteArray, QBuffer, QIODevice, QObject, Property, Slot
-from PySide2.QtGui import QPixmap, QIcon, QWindow
-from PySide2.QtQml import QQmlApplicationEngine
-from PySide2.QtWidgets import QSystemTrayIcon, QMenu, QApplication
+from PyQt5.QtCore import QByteArray, QBuffer, QIODevice, QObject, pyqtSlot, pyqtProperty
+from PyQt5.QtGui import QPixmap, QIcon
+from PyQt5.QtQml import QQmlApplicationEngine
+from PyQt5.QtQuick import QQuickWindow
+from PyQt5.QtWidgets import QSystemTrayIcon, QMenu, QApplication
 
-from fastocr.bus import AppDBusObject
 from fastocr.grabber import CaptureWidget
 from fastocr.service import OcrService
 from fastocr.setting import Setting
+from fastocr.util import DesktopInfo
+
+if DesktopInfo.dbus_supported():
+    from fastocr.bus import AppDBusObject
 
 
 # noinspection PyPep8Naming
@@ -22,7 +26,7 @@ class SettingBackend(QObject):
         super(SettingBackend, self).__init__(parent)
         self.setting = Setting()
 
-    @Slot()
+    @pyqtSlot()
     def save(self):
         self.setting.save()
 
@@ -32,7 +36,7 @@ class SettingBackend(QObject):
     def setAppid(self, text: str):
         self.setting.set('BaiduOCR', 'app_id', text)
 
-    appid = Property(str, getAppid, setAppid)
+    appid = pyqtProperty(str, getAppid, setAppid)
 
     def getApikey(self) -> str:
         return self.setting.get('BaiduOCR', 'api_key')
@@ -40,7 +44,7 @@ class SettingBackend(QObject):
     def setApikey(self, text: str):
         self.setting.set('BaiduOCR', 'api_key', text)
 
-    apikey = Property(str, getApikey, setApikey)
+    apikey = pyqtProperty(str, getApikey, setApikey)
 
     def getSeckey(self) -> str:
         return self.setting.get('BaiduOCR', 'secret_key')
@@ -48,7 +52,7 @@ class SettingBackend(QObject):
     def setSeckey(self, text: str):
         self.setting.set('BaiduOCR', 'secret_key', text)
 
-    seckey = Property(str, getSeckey, setSeckey)
+    seckey = pyqtProperty(str, getSeckey, setSeckey)
 
     def getAccurate(self) -> bool:
         return self.setting.get_boolean('BaiduOCR', 'use_accurate_mode')
@@ -56,7 +60,7 @@ class SettingBackend(QObject):
     def setAccurate(self, checked: bool):
         self.setting.set('BaiduOCR', 'use_accurate_mode', '1' if checked else '0')
 
-    accurate = Property(bool, getAccurate, setAccurate)
+    accurate = pyqtProperty(bool, getAccurate, setAccurate)
 
     def getLanguages(self) -> List[str]:
         languages_str = self.setting.get('BaiduOCR', 'languages')
@@ -67,17 +71,44 @@ class SettingBackend(QObject):
     def setLanguages(self, langs: List[str]):
         self.setting.set('BaiduOCR', 'languages', json.dumps(langs))
 
-    languages = Property(list, getLanguages, setLanguages)
+    languages = pyqtProperty(list, getLanguages, setLanguages)
+
+    def getYdAppid(self) -> str:
+        return self.setting.get('YoudaoOCR', 'app_id')
+
+    def setYdAppid(self, text: str):
+        self.setting.set('YoudaoOCR', 'app_id', text)
+
+    yd_appid = pyqtProperty(str, getYdAppid, setYdAppid)
+
+    def getYdSeckey(self) -> str:
+        return self.setting.get('YoudaoOCR', 'secret_key')
+
+    def setYdSeckey(self, text: str):
+        self.setting.set('YoudaoOCR', 'secret_key', text)
+
+    yd_seckey = pyqtProperty(str, getYdSeckey, setYdSeckey)
+
+    def getDefaultBackend(self) -> str:
+        res = self.setting.get('General', 'default_backend')
+        if res == '':
+            return 'baidu'
+        return res
+
+    def setDefaultBackend(self, backend):
+        self.setting.set('General', 'default_backend', backend)
+
+    default_backend = pyqtProperty(str, getDefaultBackend, setDefaultBackend)
 
 
 class AppTray(QSystemTrayIcon):
     def __init__(self, bus=None):
         super(AppTray, self).__init__()
         self.setting = None
-        self.bus: Optional[AppDBusObject] = bus
+        self.bus: Optional['AppDBusObject'] = bus
         self.capture_widget: Optional[CaptureWidget] = None
         self.engine: Optional[QQmlApplicationEngine] = None
-        self.setting_window: Optional[QWindow] = None
+        self.setting_window: Optional[QQuickWindow] = None
         self.backend: Optional[SettingBackend] = None
         self.language_actions = dict()
         self.load_qml()
@@ -93,16 +124,13 @@ class AppTray(QSystemTrayIcon):
 
     # noinspection PyUnresolvedReferences
     def initialize(self):
-        palette = QApplication.palette()
-        back_color = palette.color(palette.Normal, palette.Window)
-        lightness = back_color.lightness()
-        if lightness >= 180:
-            QIcon.setFallbackSearchPaths(
-                QIcon.fallbackSearchPaths() + [(Path(__file__).parent / 'resource' / 'icon' / 'dark').as_posix()])
+        loop = asyncio.get_event_loop()
+        is_dark = loop.run_until_complete(DesktopInfo.is_dark_mode())
+        if not is_dark:
+            path = Path(__file__).parent / 'resource' / 'icon' / 'dark'
         else:
-            QIcon.setFallbackSearchPaths(
-                QIcon.fallbackSearchPaths() + [(Path(__file__).parent / 'resource' / 'icon' / 'light').as_posix()])
-        self.setIcon(QIcon.fromTheme('fastocr-tray'))
+            path = Path(__file__).parent / 'resource' / 'icon' / 'light'
+        self.setIcon(QIcon.fromTheme('fastocr-tray', QIcon((path / 'fastocr-tray.svg').as_posix())))
         self.activated.connect(self.activate_action)
         # Context menu
         self.setContextMenu(QMenu())
@@ -166,8 +194,11 @@ class AppTray(QSystemTrayIcon):
     @qasync.asyncSlot(QPixmap)
     async def start_ocr(self, no_copy: bool = False, lang='', pixmap: QPixmap = None):
         self.capture_widget.close()
-        result = await OcrService().basic_general_ocr(self.pixmap_to_bytes(pixmap), lang=lang)
-        data = '\n'.join([w_.get('words', '') for w_ in result.get('words_result', [])])
+        default = self.setting.get('General', 'default_backend')
+        if default == '':
+            default = 'baidu'
+        result = await OcrService(default).basic_general_ocr(self.pixmap_to_bytes(pixmap), lang=lang)
+        data = '\n'.join(result)
         if no_copy:
             if self.bus is not None:
                 self.bus.captured(data)
@@ -188,8 +219,8 @@ class AppTray(QSystemTrayIcon):
         self.capture_widget.captured.connect(partial(self.start_ocr, no_copy, lang))
         self.capture_widget.showFullScreen()
 
-    @qasync.asyncSlot(str)
-    async def start_capture_lang(self, lang):
+    @qasync.asyncSlot()
+    async def start_capture_lang(self, lang, _):
         await self.run_capture(.5, lang=lang)
 
     @qasync.asyncSlot()
